/*
 * This file is part of react-svg-buttons.
 *
 * (c) Raphaël Benitte
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
'use strict';

Object.defineProperty(exports, '__esModule', {
    value: true
});

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _reactTweenState = require('react-tween-state');

var _reactTweenState2 = _interopRequireDefault(_reactTweenState);

var _pathHelper = require('./pathHelper');

function computeValues(completion, props) {
    var size = props.size;
    var thickness = props.thickness;

    var radius = size / 2 - thickness;
    var circumference = 2 * radius * Math.PI;

    return {
        circleDashOffset: circumference * completion,
        circleRotation: -90 + 180 * completion,
        crossRotation: 90 * completion
    };
}

exports['default'] = _react2['default'].createClass({
    displayName: 'PlusButton',

    propTypes: {
        size: _react.PropTypes.number.isRequired,
        thickness: _react.PropTypes.number.isRequired,
        color: _react.PropTypes.string.isRequired,
        transitionDuration: _react.PropTypes.number.isRequired,
        outline: _react.PropTypes.bool.isRequired
    },

    mixins: [_reactTweenState2['default'].Mixin],

    getDefaultProps: function getDefaultProps() {
        return {
            size: 52,
            thickness: 2,
            color: '#000',
            transitionDuration: 1600,
            outline: true
        };
    },

    getInitialState: function getInitialState() {
        return {
            completion: 0
        };
    },

    onMouseEnter: function onMouseEnter() {
        var transitionDuration = this.props.transitionDuration;

        this.tweenState('completion', {
            easing: _reactTweenState.easingTypes.easeOutElastic,
            stackBehavior: _reactTweenState.stackBehavior.ADDITIVE,
            duration: transitionDuration,
            endValue: 1
        });
    },

    onMouseLeave: function onMouseLeave() {
        var transitionDuration = this.props.transitionDuration;

        this.tweenState('completion', {
            easing: _reactTweenState.easingTypes.easeInQuad,
            stackBehavior: _reactTweenState.stackBehavior.ADDITIVE,
            duration: transitionDuration / 8,
            endValue: 0
        });
    },

    render: function render() {
        var _props = this.props;
        var size = _props.size;
        var thickness = _props.thickness;
        var color = _props.color;
        var outline = _props.outline;

        var originX = size / 2;
        var originY = size / 2;
        var radius = size / 2 - thickness;
        var circumference = 2 * radius * Math.PI;

        var completion = this.getTweeningValue('completion');
        var values = computeValues(completion, this.props);

        var circleDashOffset = values.circleDashOffset;
        var circleRotation = values.circleRotation;
        var crossRotation = values.crossRotation;

        var leftPathLine = (0, _pathHelper.pathCommands)([{ command: 'M', x: radius * -0.7, y: 0 }, { command: 'L', x: radius * 0.7, y: 0 }]);

        var rightPathLine = (0, _pathHelper.pathCommands)([{ command: 'M', x: 0, y: radius * -0.7 }, { command: 'L', x: 0, y: radius * 0.7 }]);

        var sparks = [0, 1, 2, 3].map(function (index) {
            return _react2['default'].createElement(
                'g',
                {
                    key: 'spark_' + index,
                    transform: 'translate(' + originX + ', ' + originY + ') rotate(' + (index * 90 + 45) + ', 0, 0)'
                },
                _react2['default'].createElement('line', {
                    fill: 'none', stroke: color, strokeWidth: thickness,
                    x1: '0', y1: radius * -0.6 * completion,
                    x2: '0', y2: radius * -0.9 * completion
                })
            );
        });

        var circle = null;
        if (outline === true) {
            circle = _react2['default'].createElement(
                'g',
                { transform: 'translate(' + originX + ', ' + originY + ') rotate(' + circleRotation + ', 0, 0)' },
                _react2['default'].createElement('circle', {
                    fill: 'none', stroke: color, strokeWidth: thickness, r: radius,
                    style: { strokeDasharray: circumference, strokeDashoffset: '' + circleDashOffset }
                })
            );
        }

        return _react2['default'].createElement(
            'span',
            { className: 'plus_button' },
            _react2['default'].createElement(
                'svg',
                {
                    width: size, height: size, xmlns: 'http://www.w3.org/svg/2000',
                    onMouseEnter: this.onMouseEnter, onMouseLeave: this.onMouseLeave
                },
                circle,
                _react2['default'].createElement(
                    'g',
                    { transform: 'translate(' + originX + ', ' + originY + ') rotate(' + crossRotation + ', 0, 0)' },
                    _react2['default'].createElement('path', { fill: 'none', stroke: color, strokeWidth: thickness, d: leftPathLine }),
                    _react2['default'].createElement('path', { fill: 'none', stroke: color, strokeWidth: thickness, d: rightPathLine })
                ),
                sparks
            )
        );
    }
});
module.exports = exports['default'];